"use strict";
/// <reference path="../../../node_modules/@types/jquery/JQueryStatic.d.ts" />
Object.defineProperty(exports, "__esModule", { value: true });
exports.JQueryClient = void 0;
const http_client_base_1 = require("@odata2ts/http-client-base");
const AjaxRequestConfig_1 = require("./AjaxRequestConfig");
const JQueryClientError_1 = require("./JQueryClientError");
class JQueryClient extends http_client_base_1.BaseHttpClient {
    constructor(jquery, config, clientOptions) {
        super(clientOptions);
        this.clientOptions = clientOptions;
        this.client = jquery;
        this.config = (0, AjaxRequestConfig_1.getDefaultConfig)(config);
    }
    mapHeaders(jqXhr) {
        return jqXhr
            .getAllResponseHeaders()
            .trim()
            .split(/[\r\n]+/)
            .reduce((collector, line) => {
            const parts = line.split(": ");
            const header = parts.shift();
            const value = parts.join(": ");
            if (header) {
                collector[header.toLowerCase()] = value;
            }
            return collector;
        }, {});
    }
    addHeaderToRequestConfig(headers, config) {
        return (0, AjaxRequestConfig_1.mergeAjaxConfig)(config, { headers });
    }
    executeRequest(method, url, data, requestConfig) {
        const mergedConfig = (0, AjaxRequestConfig_1.mergeAjaxConfig)(this.config, requestConfig);
        mergedConfig.method = method;
        mergedConfig.url = url;
        mergedConfig.data = JSON.stringify(data);
        // the actual request
        return new Promise((resolve, reject) => {
            this.client.ajax(Object.assign(Object.assign({}, mergedConfig), { success: (response, textStatus, jqXHR) => {
                    resolve({
                        status: jqXHR.status,
                        statusText: jqXHR.statusText,
                        headers: this.mapHeaders(jqXHR),
                        data: response,
                    });
                }, error: (jqXHR, textStatus, thrownError) => {
                    const responseMessage = this.retrieveErrorMessage(jqXHR.responseJSON);
                    const errorMessage = responseMessage
                        ? "Server responded with error: " + responseMessage
                        : textStatus + " " + thrownError;
                    const responseHeaders = this.mapHeaders(jqXHR);
                    reject(new JQueryClientError_1.JQueryClientError(errorMessage, jqXHR.status, responseHeaders, new Error(thrownError), jqXHR));
                } }));
        });
    }
}
exports.JQueryClient = JQueryClient;
//# sourceMappingURL=JQueryClient.js.map